@@ -19,6 +19,8 @@ class Client:
         self.local = local
 
     def start_new_activity(self, name, request):
+        name = name.replace('_', '-') # TODO no longer need to do this once have unique names
+        name = name.lower()
         # with grpc.insecure_channel('localhost:50051') as channel:
         if self.local:
             endpoint = 'localhost:50051'
